{ modulesPath, pkgs, config, ... }:

{
  imports = [
    # Include the default lxd configuration.
    "${modulesPath}/virtualisation/proxmox-lxc.nix"
    # Include the container-specific autogenerated configuration.
    ./lxd.nix
    ./services/opengist.nix
    ./services/kener.nix
    #./services/upsnap.nix
  ];

  networking = {
    dhcpcd.enable = false;
    useDHCP = false;
    useHostResolvConf = false;
    firewall.enable = false;
  };

  environment.systemPackages = with pkgs; [
    git
    curl
    vim
  ];

  # services.upsnap = {
  #   enable = true;
  # };

  services.kener = {
    enable = true;
  };

  # Would like to use my PG DB for this but the service just doesn't 
  # support DBs that are hosted outside of the Nix box
  services.writefreely = {
    enable = true;
    host = "write.amy.mov";

    database = {
      type = "sqlite3";
    };

    admin = {
      name = "amy";
    };

    settings = {
      server = {
        bind = "0.0.0.0";
        port = 8123;
      };
    };
  };

  services.opengist = {
    enable = true;
    config = ./opengist.yml;
  };

  services.atticd = {
    enable = true;

    # Replace with absolute path to your environment file
    environmentFile = config.age.secrets."atticd.env".path;

    settings = {
      listen = "0.0.0.0:8080";

      jwt = { };

      # Data chunking
      #
      # Warning: If you change any of the values here, it will be
      # difficult to reuse existing chunks for newly-uploaded NARs
      # since the cutpoints will be different. As a result, the
      # deduplication ratio will suffer for a while after the change.
      chunking = {
        # The minimum NAR size to trigger chunking
        #
        # If 0, chunking is disabled entirely for newly-uploaded NARs.
        # If 1, all NARs are chunked.
        nar-size-threshold = 64 * 1024; # 64 KiB

        # The preferred minimum size of a chunk, in bytes
        min-size = 16 * 1024; # 16 KiB

        # The preferred average size of a chunk, in bytes
        avg-size = 64 * 1024; # 64 KiB

        # The preferred maximum size of a chunk, in bytes
        max-size = 256 * 1024; # 256 KiB
      };
    };
  };

  systemd.network = {
    enable = true;
    networks."50-eth0" = {
      matchConfig.Name = "eth0";
      networkConfig = {
        DHCP = "ipv4";
        IPv6AcceptRA = true;
      };
      linkConfig.RequiredForOnline = "routable";
    };
  };

  system.stateVersion = "24.11"; # Did you read the comment?
}
